==> kea-2.6.3-2.1-x86_64.pkg.tar.zst: usr/share/kea/scripts/pgsql/upgrade_020_to_021.sh <==
#!/bin/sh

# Copyright (C) 2023-2024 Internet Systems Consortium, Inc. ("ISC")
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

# Exit with error if commands exit with non-zero and if undefined variables are
# used.
set -eu

# shellcheck disable=SC2034
# SC2034: ... appears unused. Verify use (or export if used externally).
prefix="/usr"

# Include utilities based on location of this script. Check for sources first,
# so that the unexpected situations with weird paths fall on the default
# case of installed.
script_path=$(cd "$(dirname "${0}")" && pwd)
if test "${script_path}" = "/startdir/src/kea-2.6.3/src/share/database/scripts/pgsql"; then
    # shellcheck source=./src/bin/admin/admin-utils.sh.in
    . "/startdir/src/kea-2.6.3/src/bin/admin/admin-utils.sh"
else
    # shellcheck source=./src/bin/admin/admin-utils.sh.in
    . "${prefix}/share/kea/scripts/admin-utils.sh"
fi

VERSION=$(pgsql_version "$@")

if [ "$VERSION" != "20.0" ]; then
    printf 'This script upgrades 20.0 to 21.0. '
    printf 'Reported version is %s. Skipping upgrade.\n' "${VERSION}"
    exit 0
fi

psql "$@" >/dev/null <<EOF
START TRANSACTION;

-- This line starts the schema upgrade to version 21.0.

-- Correct dhcp4_server_modification_ts to index the dhcp4_server table.
DROP INDEX dhcp4_server_modification_ts;
CREATE INDEX dhcp4_server_modification_ts ON dhcp4_server (modification_ts);

-- Update the schema version number.
UPDATE schema_version
    SET version = '21', minor = '0';

-- This line concludes the schema upgrade to version 21.0.

-- Commit the script transaction.
COMMIT;

EOF

==> kea-3.0.0-7-x86_64.pkg.tar.zst: usr/share/kea/scripts/pgsql/upgrade_020_to_021.sh <==
#!/bin/sh

# Copyright (C) 2023-2025 Internet Systems Consortium, Inc. ("ISC")
#
# This Source Code Form is subject to the terms of the Mozilla Public
# License, v. 2.0. If a copy of the MPL was not distributed with this
# file, You can obtain one at http://mozilla.org/MPL/2.0/.

# Exit with error if commands exit with non-zero and if undefined variables are
# used.
set -eu

# shellcheck disable=SC2034
# SC2034: ... appears unused. Verify use (or export if used externally).
prefix="/usr"

# Include utilities based on location of this script. Check for sources first,
# so that the unexpected situations with weird paths fall on the default
# case of installed.
script_path=$(cd "$(dirname "${0}")" && pwd)
if test "${script_path}" = "/build/kea/src/build/src/share/database/scripts/pgsql"; then
    # shellcheck source=./src/bin/admin/admin-utils.sh.in
    . "/build/kea/src/build/src/bin/admin/admin-utils.sh"
else
    # shellcheck source=./src/bin/admin/admin-utils.sh.in
    . "${prefix}/share/kea/scripts/admin-utils.sh"
fi

VERSION=$(pgsql_version "$@")

if [ "$VERSION" != "20.0" ]; then
    printf 'This script upgrades 20.0 to 21.0. '
    printf 'Reported version is %s. Skipping upgrade.\n' "${VERSION}"
    exit 0
fi

psql "$@" >/dev/null <<EOF
START TRANSACTION;

-- This line starts the schema upgrade to version 21.0.

-- Correct dhcp4_server_modification_ts to index the dhcp4_server table.
DROP INDEX dhcp4_server_modification_ts;
CREATE INDEX dhcp4_server_modification_ts ON dhcp4_server (modification_ts);

-- Update the schema version number.
UPDATE schema_version
    SET version = '21', minor = '0';

-- This line concludes the schema upgrade to version 21.0.

-- Commit the script transaction.
COMMIT;

EOF
